==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/outputs/FleetLaunchTemplateConfigOverrideInstanceRequirements.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin.outputs

import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property acceleratorCount Block describing the minimum and maximum number of accelerators (GPUs, FPGAs, or AWS Inferentia chips). Default is no minimum or maximum limits.
 * @property acceleratorManufacturers List of accelerator manufacturer names. Default is any manufacturer.
 * @property acceleratorNames List of accelerator names. Default is any acclerator.
 * @property acceleratorTotalMemoryMib Block describing the minimum and maximum total memory of the accelerators. Default is no minimum or maximum.
 * @property acceleratorTypes The accelerator types that must be on the instance type. Default is any accelerator type.
 * @property allowedInstanceTypes The instance types to apply your specified attributes against. All other instance types are ignored, even if they match your specified attributes. You can use strings with one or more wild cards,represented by an asterisk (\*). The following are examples: `c5*`, `m5a.*`, `r*`, `*3*`. For example, if you specify `c5*`, you are excluding the entire C5 instance family, which includes all C5a and C5n instance types. If you specify `m5a.*`, you are excluding all the M5a instance types, but not the M5n instance types. Maximum of 400 entries in the list; each entry is limited to 30 characters. Default is no excluded instance types. Default is any instance type.
 * If you specify `AllowedInstanceTypes`, you can't specify `ExcludedInstanceTypes`.
 * @property bareMetal Indicate whether bare metal instace types should be `included`, `excluded`, or `required`. Default is `excluded`.
 * @property baselineEbsBandwidthMbps Block describing the minimum and maximum baseline EBS bandwidth, in Mbps. Default is no minimum or maximum.
 * @property burstablePerformance Indicates whether burstable performance T instance types are `included`, `excluded`, or `required`. Default is `excluded`.
 * @property cpuManufacturers The CPU manufacturers to include. Default is any manufacturer.
 * > **NOTE:** Don't confuse the CPU hardware manufacturer with the CPU hardware architecture. Instances will be launched with a compatible CPU architecture based on the Amazon Machine Image (AMI) that you specify in your launch template.
 * @property excludedInstanceTypes The instance types to exclude. You can use strings with one or more wild cards, represented by an asterisk (\*). The following are examples: `c5*`, `m5a.*`, `r*`, `*3*`. For example, if you specify `c5*`, you are excluding the entire C5 instance family, which includes all C5a and C5n instance types. If you specify `m5a.*`, you are excluding all the M5a instance types, but not the M5n instance types. Maximum of 400 entries in the list; each entry is limited to 30 characters. Default is no excluded instance types.
 * If you specify `AllowedInstanceTypes`, you can't specify `ExcludedInstanceTypes`.
 * @property instanceGenerations Indicates whether current or previous generation instance types are included. The current generation instance types are recommended for use. Valid values are `current` and `previous`. Default is `current` and `previous` generation instance types.
 * @property localStorage Indicate whether instance types with local storage volumes are `included`, `excluded`, or `required`. Default is `included`.
 * @property localStorageTypes List of local storage type names. Valid values are `hdd` and `ssd`. Default any storage type.
 * @property memoryGibPerVcpu Block describing the minimum and maximum amount of memory (GiB) per vCPU. Default is no minimum or maximum.
 * @property memoryMib The minimum and maximum amount of memory per vCPU, in GiB. Default is no minimum or maximum limits.
 * @property networkBandwidthGbps The minimum and maximum amount of network bandwidth, in gigabits per second (Gbps). Default is No minimum or maximum.
 * @property networkInterfaceCount Block describing the minimum and maximum number of network interfaces. Default is no minimum or maximum.
 * @property onDemandMaxPricePercentageOverLowestPrice The price protection threshold for On-Demand Instances. This is the maximum you’ll pay for an On-Demand Instance, expressed as a percentage higher than the cheapest M, C, or R instance type with your specified attributes. When Amazon EC2 Auto Scaling selects instance types with your attributes, we will exclude instance types whose price is higher than your threshold. The parameter accepts an integer, which Amazon EC2 Auto Scaling interprets as a percentage. To turn off price protection, specify a high value, such as 999999. Default is 20.
 * If you set `target_capacity_unit_type` to `vcpu` or `memory-mib`, the price protection threshold is applied based on the per-vCPU or per-memory price instead of the per-instance price.
 * @property requireHibernateSupport Indicate whether instance types must support On-Demand Instance Hibernation, either `true` or `false`. Default is `false`.
 * @property spotMaxPricePercentageOverLowestPrice The price protection threshold for Spot Instances. This is the maximum you’ll pay for a Spot Instance, expressed as a percentage higher than the cheapest M, C, or R instance type with your specified attributes. When Amazon EC2 Auto Scaling selects instance types with your attributes, we will exclude instance types whose price is higher than your threshold. The parameter accepts an integer, which Amazon EC2 Auto Scaling interprets as a percentage. To turn off price protection, specify a high value, such as 999999. Default is 100.
 * If you set DesiredCapacityType to vcpu or memory-mib, the price protection threshold is applied based on the per vCPU or per memory price instead of the per instance price.
 * @property totalLocalStorageGb Block describing the minimum and maximum total local storage (GB). Default is no minimum or maximum.
 * @property vcpuCount Block describing the minimum and maximum number of vCPUs. Default is no maximum.
 */
public data class FleetLaunchTemplateConfigOverrideInstanceRequirements(
    public val acceleratorCount:
    FleetLaunchTemplateConfigOverrideInstanceRequirementsAcceleratorCount? = null,
    public val acceleratorManufacturers: List<String>? = null,
    public val acceleratorNames: List<String>? = null,
    public val acceleratorTotalMemoryMib:
    FleetLaunchTemplateConfigOverrideInstanceRequirementsAcceleratorTotalMemoryMib? = null,
    public val acceleratorTypes: List<String>? = null,
    public val allowedInstanceTypes: List<String>? = null,
    public val bareMetal: String? = null,
    public val baselineEbsBandwidthMbps:
    FleetLaunchTemplateConfigOverrideInstanceRequirementsBaselineEbsBandwidthMbps? = null,
    public val burstablePerformance: String? = null,
    public val cpuManufacturers: List<String>? = null,
    public val excludedInstanceTypes: List<String>? = null,
    public val instanceGenerations: List<String>? = null,
    public val localStorage: String? = null,
    public val localStorageTypes: List<String>? = null,
    public val memoryGibPerVcpu:
    FleetLaunchTemplateConfigOverrideInstanceRequirementsMemoryGibPerVcpu? = null,
    public val memoryMib: FleetLaunchTemplateConfigOverrideInstanceRequirementsMemoryMib,
    public val networkBandwidthGbps:
    FleetLaunchTemplateConfigOverrideInstanceRequirementsNetworkBandwidthGbps? = null,
    public val networkInterfaceCount:
    FleetLaunchTemplateConfigOverrideInstanceRequirementsNetworkInterfaceCount? = null,
    public val onDemandMaxPricePercentageOverLowestPrice: Int? = null,
    public val requireHibernateSupport: Boolean? = null,
    public val spotMaxPricePercentageOverLowestPrice: Int? = null,
    public val totalLocalStorageGb:
    FleetLaunchTemplateConfigOverrideInstanceRequirementsTotalLocalStorageGb? = null,
    public val vcpuCount: FleetLaunchTemplateConfigOverrideInstanceRequirementsVcpuCount,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.ec2.outputs.FleetLaunchTemplateConfigOverrideInstanceRequirements):
            FleetLaunchTemplateConfigOverrideInstanceRequirements =
            FleetLaunchTemplateConfigOverrideInstanceRequirements(
                acceleratorCount = javaType.acceleratorCount().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.ec2.kotlin.outputs.FleetLaunchTemplateConfigOverrideInstanceRequirementsAcceleratorCount.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                acceleratorManufacturers = javaType.acceleratorManufacturers().map({ args0 -> args0 }),
                acceleratorNames = javaType.acceleratorNames().map({ args0 -> args0 }),
                acceleratorTotalMemoryMib = javaType.acceleratorTotalMemoryMib().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.ec2.kotlin.outputs.FleetLaunchTemplateConfigOverrideInstanceRequirementsAcceleratorTotalMemoryMib.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                acceleratorTypes = javaType.acceleratorTypes().map({ args0 -> args0 }),
                allowedInstanceTypes = javaType.allowedInstanceTypes().map({ args0 -> args0 }),
                bareMetal = javaType.bareMetal().map({ args0 -> args0 }).orElse(null),
                baselineEbsBandwidthMbps = javaType.baselineEbsBandwidthMbps().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.ec2.kotlin.outputs.FleetLaunchTemplateConfigOverrideInstanceRequirementsBaselineEbsBandwidthMbps.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                burstablePerformance = javaType.burstablePerformance().map({ args0 -> args0 }).orElse(null),
                cpuManufacturers = javaType.cpuManufacturers().map({ args0 -> args0 }),
                excludedInstanceTypes = javaType.excludedInstanceTypes().map({ args0 -> args0 }),
                instanceGenerations = javaType.instanceGenerations().map({ args0 -> args0 }),
                localStorage = javaType.localStorage().map({ args0 -> args0 }).orElse(null),
                localStorageTypes = javaType.localStorageTypes().map({ args0 -> args0 }),
                memoryGibPerVcpu = javaType.memoryGibPerVcpu().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.ec2.kotlin.outputs.FleetLaunchTemplateConfigOverrideInstanceRequirementsMemoryGibPerVcpu.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                memoryMib = javaType.memoryMib().let({ args0 ->
                    com.pulumi.aws.ec2.kotlin.outputs.FleetLaunchTemplateConfigOverrideInstanceRequirementsMemoryMib.Companion.toKotlin(args0)
                }),
                networkBandwidthGbps = javaType.networkBandwidthGbps().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.ec2.kotlin.outputs.FleetLaunchTemplateConfigOverrideInstanceRequirementsNetworkBandwidthGbps.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                networkInterfaceCount = javaType.networkInterfaceCount().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.ec2.kotlin.outputs.FleetLaunchTemplateConfigOverrideInstanceRequirementsNetworkInterfaceCount.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                onDemandMaxPricePercentageOverLowestPrice = javaType.onDemandMaxPricePercentageOverLowestPrice().map({ args0 ->
                    args0
                }).orElse(null),
                requireHibernateSupport = javaType.requireHibernateSupport().map({ args0 -> args0 }).orElse(null),
                spotMaxPricePercentageOverLowestPrice = javaType.spotMaxPricePercentageOverLowestPrice().map({ args0 ->
                    args0
                }).orElse(null),
                totalLocalStorageGb = javaType.totalLocalStorageGb().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.ec2.kotlin.outputs.FleetLaunchTemplateConfigOverrideInstanceRequirementsTotalLocalStorageGb.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                vcpuCount = javaType.vcpuCount().let({ args0 ->
                    com.pulumi.aws.ec2.kotlin.outputs.FleetLaunchTemplateConfigOverrideInstanceRequirementsVcpuCount.Companion.toKotlin(args0)
                }),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/outputs/FleetLaunchTemplateConfigOverrideInstanceRequirements.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin.outputs

import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property acceleratorCount Block describing the minimum and maximum number of accelerators (GPUs, FPGAs, or AWS Inferentia chips). Default is no minimum or maximum limits.
 * @property acceleratorManufacturers List of accelerator manufacturer names. Default is any manufacturer.
 * @property acceleratorNames List of accelerator names. Default is any acclerator.
 * @property acceleratorTotalMemoryMib Block describing the minimum and maximum total memory of the accelerators. Default is no minimum or maximum.
 * @property acceleratorTypes The accelerator types that must be on the instance type. Default is any accelerator type.
 * @property allowedInstanceTypes The instance types to apply your specified attributes against. All other instance types are ignored, even if they match your specified attributes. You can use strings with one or more wild cards,represented by an asterisk (\*). The following are examples: `c5*`, `m5a.*`, `r*`, `*3*`. For example, if you specify `c5*`, you are excluding the entire C5 instance family, which includes all C5a and C5n instance types. If you specify `m5a.*`, you are excluding all the M5a instance types, but not the M5n instance types. Maximum of 400 entries in the list; each entry is limited to 30 characters. Default is no excluded instance types. Default is any instance type.
 * If you specify `AllowedInstanceTypes`, you can't specify `ExcludedInstanceTypes`.
 * @property bareMetal Indicate whether bare metal instace types should be `included`, `excluded`, or `required`. Default is `excluded`.
 * @property baselineEbsBandwidthMbps Block describing the minimum and maximum baseline EBS bandwidth, in Mbps. Default is no minimum or maximum.
 * @property burstablePerformance Indicates whether burstable performance T instance types are `included`, `excluded`, or `required`. Default is `excluded`.
 * @property cpuManufacturers The CPU manufacturers to include. Default is any manufacturer.
 * > **NOTE:** Don't confuse the CPU hardware manufacturer with the CPU hardware architecture. Instances will be launched with a compatible CPU architecture based on the Amazon Machine Image (AMI) that you specify in your launch template.
 * @property excludedInstanceTypes The instance types to exclude. You can use strings with one or more wild cards, represented by an asterisk (\*). The following are examples: `c5*`, `m5a.*`, `r*`, `*3*`. For example, if you specify `c5*`, you are excluding the entire C5 instance family, which includes all C5a and C5n instance types. If you specify `m5a.*`, you are excluding all the M5a instance types, but not the M5n instance types. Maximum of 400 entries in the list; each entry is limited to 30 characters. Default is no excluded instance types.
 * If you specify `AllowedInstanceTypes`, you can't specify `ExcludedInstanceTypes`.
 * @property instanceGenerations Indicates whether current or previous generation instance types are included. The current generation instance types are recommended for use. Valid values are `current` and `previous`. Default is `current` and `previous` generation instance types.
 * @property localStorage Indicate whether instance types with local storage volumes are `included`, `excluded`, or `required`. Default is `included`.
 * @property localStorageTypes List of local storage type names. Valid values are `hdd` and `ssd`. Default any storage type.
 * @property maxSpotPriceAsPercentageOfOptimalOnDemandPrice The price protection threshold for Spot Instances. This is the maximum you’ll pay for a Spot Instance, expressed as a percentage higher than the cheapest M, C, or R instance type with your specified attributes. When Amazon EC2 Auto Scaling selects instance types with your attributes, we will exclude instance types whose price is higher than your threshold. The parameter accepts an integer, which Amazon EC2 Auto Scaling interprets as a percentage. To turn off price protection, specify a high value, such as 999999. Conflicts with `spot_max_price_percentage_over_lowest_price`
 * @property memoryGibPerVcpu Block describing the minimum and maximum amount of memory (GiB) per vCPU. Default is no minimum or maximum.
 * @property memoryMib The minimum and maximum amount of memory per vCPU, in GiB. Default is no minimum or maximum limits.
 * @property networkBandwidthGbps The minimum and maximum amount of network bandwidth, in gigabits per second (Gbps). Default is No minimum or maximum.
 * @property networkInterfaceCount Block describing the minimum and maximum number of network interfaces. Default is no minimum or maximum.
 * @property onDemandMaxPricePercentageOverLowestPrice The price protection threshold for On-Demand Instances. This is the maximum you’ll pay for an On-Demand Instance, expressed as a percentage higher than the cheapest M, C, or R instance type with your specified attributes. When Amazon EC2 Auto Scaling selects instance types with your attributes, we will exclude instance types whose price is higher than your threshold. The parameter accepts an integer, which Amazon EC2 Auto Scaling interprets as a percentage. To turn off price protection, specify a high value, such as 999999. Default is 20.
 * If you set `target_capacity_unit_type` to `vcpu` or `memory-mib`, the price protection threshold is applied based on the per-vCPU or per-memory price instead of the per-instance price.
 * @property requireHibernateSupport Indicate whether instance types must support On-Demand Instance Hibernation, either `true` or `false`. Default is `false`.
 * @property spotMaxPricePercentageOverLowestPrice The price protection threshold for Spot Instances. This is the maximum you’ll pay for a Spot Instance, expressed as a percentage higher than the cheapest M, C, or R instance type with your specified attributes. When Amazon EC2 Auto Scaling selects instance types with your attributes, we will exclude instance types whose price is higher than your threshold. The parameter accepts an integer, which Amazon EC2 Auto Scaling interprets as a percentage. To turn off price protection, specify a high value, such as 999999. Default is 100. Conflicts with `max_spot_price_as_percentage_of_optimal_on_demand_price`
 * If you set DesiredCapacityType to vcpu or memory-mib, the price protection threshold is applied based on the per vCPU or per memory price instead of the per instance price.
 * @property totalLocalStorageGb Block describing the minimum and maximum total local storage (GB). Default is no minimum or maximum.
 * @property vcpuCount Block describing the minimum and maximum number of vCPUs. Default is no maximum.
 */
public data class FleetLaunchTemplateConfigOverrideInstanceRequirements(
    public val acceleratorCount: FleetLaunchTemplateConfigOverrideInstanceRequirementsAcceleratorCount? = null,
    public val acceleratorManufacturers: List<String>? = null,
    public val acceleratorNames: List<String>? = null,
    public val acceleratorTotalMemoryMib: FleetLaunchTemplateConfigOverrideInstanceRequirementsAcceleratorTotalMemoryMib? = null,
    public val acceleratorTypes: List<String>? = null,
    public val allowedInstanceTypes: List<String>? = null,
    public val bareMetal: String? = null,
    public val baselineEbsBandwidthMbps: FleetLaunchTemplateConfigOverrideInstanceRequirementsBaselineEbsBandwidthMbps? = null,
    public val burstablePerformance: String? = null,
    public val cpuManufacturers: List<String>? = null,
    public val excludedInstanceTypes: List<String>? = null,
    public val instanceGenerations: List<String>? = null,
    public val localStorage: String? = null,
    public val localStorageTypes: List<String>? = null,
    public val maxSpotPriceAsPercentageOfOptimalOnDemandPrice: Int? = null,
    public val memoryGibPerVcpu: FleetLaunchTemplateConfigOverrideInstanceRequirementsMemoryGibPerVcpu? = null,
    public val memoryMib: FleetLaunchTemplateConfigOverrideInstanceRequirementsMemoryMib,
    public val networkBandwidthGbps: FleetLaunchTemplateConfigOverrideInstanceRequirementsNetworkBandwidthGbps? = null,
    public val networkInterfaceCount: FleetLaunchTemplateConfigOverrideInstanceRequirementsNetworkInterfaceCount? = null,
    public val onDemandMaxPricePercentageOverLowestPrice: Int? = null,
    public val requireHibernateSupport: Boolean? = null,
    public val spotMaxPricePercentageOverLowestPrice: Int? = null,
    public val totalLocalStorageGb: FleetLaunchTemplateConfigOverrideInstanceRequirementsTotalLocalStorageGb? = null,
    public val vcpuCount: FleetLaunchTemplateConfigOverrideInstanceRequirementsVcpuCount,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.ec2.outputs.FleetLaunchTemplateConfigOverrideInstanceRequirements): FleetLaunchTemplateConfigOverrideInstanceRequirements =
            FleetLaunchTemplateConfigOverrideInstanceRequirements(
                acceleratorCount = javaType.acceleratorCount().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.ec2.kotlin.outputs.FleetLaunchTemplateConfigOverrideInstanceRequirementsAcceleratorCount.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                acceleratorManufacturers = javaType.acceleratorManufacturers().map({ args0 -> args0 }),
                acceleratorNames = javaType.acceleratorNames().map({ args0 -> args0 }),
                acceleratorTotalMemoryMib = javaType.acceleratorTotalMemoryMib().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.ec2.kotlin.outputs.FleetLaunchTemplateConfigOverrideInstanceRequirementsAcceleratorTotalMemoryMib.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                acceleratorTypes = javaType.acceleratorTypes().map({ args0 -> args0 }),
                allowedInstanceTypes = javaType.allowedInstanceTypes().map({ args0 -> args0 }),
                bareMetal = javaType.bareMetal().map({ args0 -> args0 }).orElse(null),
                baselineEbsBandwidthMbps = javaType.baselineEbsBandwidthMbps().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.ec2.kotlin.outputs.FleetLaunchTemplateConfigOverrideInstanceRequirementsBaselineEbsBandwidthMbps.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                burstablePerformance = javaType.burstablePerformance().map({ args0 -> args0 }).orElse(null),
                cpuManufacturers = javaType.cpuManufacturers().map({ args0 -> args0 }),
                excludedInstanceTypes = javaType.excludedInstanceTypes().map({ args0 -> args0 }),
                instanceGenerations = javaType.instanceGenerations().map({ args0 -> args0 }),
                localStorage = javaType.localStorage().map({ args0 -> args0 }).orElse(null),
                localStorageTypes = javaType.localStorageTypes().map({ args0 -> args0 }),
                maxSpotPriceAsPercentageOfOptimalOnDemandPrice = javaType.maxSpotPriceAsPercentageOfOptimalOnDemandPrice().map({ args0 ->
                    args0
                }).orElse(null),
                memoryGibPerVcpu = javaType.memoryGibPerVcpu().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.ec2.kotlin.outputs.FleetLaunchTemplateConfigOverrideInstanceRequirementsMemoryGibPerVcpu.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                memoryMib = javaType.memoryMib().let({ args0 ->
                    com.pulumi.aws.ec2.kotlin.outputs.FleetLaunchTemplateConfigOverrideInstanceRequirementsMemoryMib.Companion.toKotlin(args0)
                }),
                networkBandwidthGbps = javaType.networkBandwidthGbps().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.ec2.kotlin.outputs.FleetLaunchTemplateConfigOverrideInstanceRequirementsNetworkBandwidthGbps.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                networkInterfaceCount = javaType.networkInterfaceCount().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.ec2.kotlin.outputs.FleetLaunchTemplateConfigOverrideInstanceRequirementsNetworkInterfaceCount.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                onDemandMaxPricePercentageOverLowestPrice = javaType.onDemandMaxPricePercentageOverLowestPrice().map({ args0 ->
                    args0
                }).orElse(null),
                requireHibernateSupport = javaType.requireHibernateSupport().map({ args0 -> args0 }).orElse(null),
                spotMaxPricePercentageOverLowestPrice = javaType.spotMaxPricePercentageOverLowestPrice().map({ args0 ->
                    args0
                }).orElse(null),
                totalLocalStorageGb = javaType.totalLocalStorageGb().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.ec2.kotlin.outputs.FleetLaunchTemplateConfigOverrideInstanceRequirementsTotalLocalStorageGb.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                vcpuCount = javaType.vcpuCount().let({ args0 ->
                    com.pulumi.aws.ec2.kotlin.outputs.FleetLaunchTemplateConfigOverrideInstanceRequirementsVcpuCount.Companion.toKotlin(args0)
                }),
            )
    }
}
